==> Zephyrus-2.16.3.10994.tar.gz: Zephyrus-2.16.3.10994/Zephyrus/__init__.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
# $Id: __init__.py 11002 2018-04-30 09:44:55Z Lavender $
#
# Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
#
# Licensed under the Proprietary License,
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at our web site.
#
# See the License for the specific language governing permissions and
# limitations under the License.
#
# $Author: Lavender $ (last)
# $Date: 2018-04-30 17:44:55 +0800 (週一, 30 四月 2018) $
# $Revision: 11002 $

import os
import warnings
import logging

# from django.utils.translation import ugettext_lazy as _

# django.core.exceptions.AppRegistryNotReady: The translation infrastructure 
# cannot be initialized before the apps registry is ready. 
# Check that you don't make non-lazy gettext calls at import time.

from Iuppiter.Util import extendUnique
from Iuppiter.DjangoUtil import extendInstalledApps

from Version import ZEPHYRUS_VERSION

def createLogger(name, fileHandlerName):
    logger = logging.getLogger(name)
    logger.setLevel(logging.DEBUG)
    handler = logging.StreamHandler()
    handler.setFormatter(
        logging.Formatter("%(asctime)s - %(levelname)s - %(message)s"))
    logger.addHandler(handler)
    fileHandler = logging.FileHandler(fileHandlerName)
    fileHandler.setLevel(logging.WARNING)
    logger.addHandler(fileHandler)
    return logger

def update(settingsDict, defaults, config=None):
    """
    Update settings by defaults if the key is not in settings.
    
    @param settingsDict Settings dict.
    @param defaults Defaults dict to provide default value.
    @param config Reserved.
    """
    for k, v in defaults.items():
        if k not in settingsDict:
            settingsDict[k] = v

def warnWithout(k, settingsDict, defaults):
    """
    Prompt warning message for without certain key in settings
    while doing attachSettings.
    
    @param k Settings key.
    @param settingsDict Settings dict.
    @param defaults Defaults dict to provide default value.
    """
    if k not in settingsDict:
        warnings.warn("'%s' %s %s" % (
            colored(k, 'yellow', attrs=['bold']),
            colored(" not set in settings.py, it will be set as ", 'white',
                    attrs=['bold']),
            colored(defaults[k], 'cyan', attrs=['bold'])))

def attachSettings(settingsDict):

    #=========================================================================
    # Django plugins.
    ADDING_INSTALLED_APPS = (
        'djangocms_history',
        'djangocms_forms',
        'djangocms_file',
        'djangocms_picture',
        'Zephyrus.boilerplate',
        'Zephyrus.landing',
        'Zephyrus.facebook',
        'drip',
        'Zephyrus.autoresponder',
        'Zephyrus.comment',
    )

    installed = settingsDict['INSTALLED_APPS']
    keys = [k for k in installed if k.startswith('djangocms_')]
    extendInstalledApps(settingsDict, ADDING_INSTALLED_APPS,
                        key=list(keys)[-1])
    
    #=========================================================================
    # Django CMS Ckeditor.
    DEFAULT_CKEDITOR_SETTINGS = {
        'CKEDITOR_SETTINGS': {
            'language': '{{ language }}',
            'toolbar_CMS': [
                ['cmsplugins',],
                
                ['Source', '-', 'Save', 'NewPage', 'DocProps', 'Preview', 
                 'Print', '-', ' Templates'],
                ['Cut', 'Copy', 'Paste', 'PasteText', 'PasteFromWord', '-', 
                 'Undo', 'Redo'],
                ['Find', 'Replace', '-', 'SelectAll', '-', 'SpellChecker', 
                 'Scayt'],
                ['Form', 'Checkbox', 'Radio', 'TextField', 'Textarea', 'Select', 
                'Button', 'ImageButton', 'HiddenField'],
                ['Bold', 'Italic', 'Underline', 'Strike', 'Subscript', 
                'Superscript', '-', 'RemoveFormat'],
                ['NumberedList', 'BulletedList', '-', 'Outdent', 'Indent', '-', 
                'Blockquote', 'CreateDiv', '-', 'JustifyLeft', 'JustifyCenter', 
                'JustifyRight', 'JustifyBlock', '-', 'BidiLtr', 'BidiRtl'],
                ['Link', 'Unlink', 'Anchor'],
                ['Image', 'Flash', 'Table', 'HorizontalRule', 'Smiley', 
                'SpecialChar', 'PageBreak', 'Iframe'],
                ['Styles', 'Format', 'Font', 'FontSize'],
                ['TextColor', 'BGColor'],
                ['Maximize', 'ShowBlocks', '-', 'About'],
            ],
            'toolbar_HTMLField': [         
                ['Source', '-', 'Save', 'NewPage', 'DocProps', 'Preview', 
                 'Print', '-', ' Templates'],
                ['Cut', 'Copy', 'Paste', 'PasteText', 'PasteFromWord', '-', 
                 'Undo', 'Redo'],
                ['Find', 'Replace', '-', 'SelectAll', '-', 'SpellChecker', 
                 'Scayt'],
                ['Form', 'Checkbox', 'Radio', 'TextField', 'Textarea', 'Select', 
                'Button', 'ImageButton', 'HiddenField'],
                ['Bold', 'Italic', 'Underline', 'Strike', 'Subscript', 
                'Superscript', '-', 'RemoveFormat'],
                ['NumberedList', 'BulletedList', '-', 'Outdent', 'Indent', '-', 
                'Blockquote', 'CreateDiv', '-', 'JustifyLeft', 'JustifyCenter', 
                'JustifyRight', 'JustifyBlock', '-', 'BidiLtr', 'BidiRtl'],
                ['Link', 'Unlink', 'Anchor'],
                ['Image', 'Flash', 'Table', 'HorizontalRule', 'Smiley', 
                'SpecialChar', 'PageBreak', 'Iframe'],
                ['Styles', 'Format', 'Font', 'FontSize'],
                ['TextColor', 'BGColor'],
                ['Maximize', 'ShowBlocks', '-', 'About'],
            ],
            'skin': 'moono-lisa',
        },
        'TEXT_ADDITIONAL_TAGS': (
            'iframe',
        ),
        'TEXT_ADDITIONAL_ATTRIBUTES': (
            'scrolling', 'allowfullscreen', 'frameborder'
        ),
    }
    update(settingsDict, DEFAULT_CKEDITOR_SETTINGS)

    #=========================================================================
    # Django CMS Snippe.
    DEFAULT_SNIPPE_SETTINGS = {
        'DJANGOCMS_SNIPPET_SEARCH': True,
    }
    update(settingsDict, DEFAULT_SNIPPE_SETTINGS)

    #=========================================================================
    # Zephyrus Landing.
    LANDING_FORM_SETTINGS = [
        ('djangocms_forms/form_template/default.html', 'Default'),
        ('landing/LandingForm.html', 'Landing Form'),
    ]

    LANDING_CMS_TEMPLATES = [
        ('landing/ThankYou.html', 'Landing Thank You Page'),
    ]

    if 'DJANGOCMS_FORMS_TEMPLATES' in settingsDict:
        formTemplates = settingsDict['DJANGOCMS_FORMS_TEMPLATES']
    else:
        formTemplates = LANDING_FORM_SETTINGS

    if 'CMS_TEMPLATES' in settingsDict:
        cmsTemplates = settingsDict['CMS_TEMPLATES']
    else:
        cmsTemplates = LANDING_CMS_TEMPLATES


    settingsDict['DJANGOCMS_FORMS_TEMPLATES'] = extendUnique(
        formTemplates, LANDING_FORM_SETTINGS)
    settingsDict['CMS_TEMPLATES'] = extendUnique(
        cmsTemplates, LANDING_CMS_TEMPLATES)

==> Zephyrus-2.17.0.11020.tar.gz: Zephyrus-2.17.0.11020/Zephyrus/__init__.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
# $Id: __init__.py 11012 2018-05-06 05:58:39Z Lavender $
#
# Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
#
# Licensed under the Proprietary License,
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at our web site.
#
# See the License for the specific language governing permissions and
# limitations under the License.
#
# $Author: Lavender $ (last)
# $Date: 2018-05-06 13:58:39 +0800 (週日, 06 五月 2018) $
# $Revision: 11012 $

import os
import warnings
import logging

# from django.utils.translation import ugettext_lazy as _

# django.core.exceptions.AppRegistryNotReady: The translation infrastructure 
# cannot be initialized before the apps registry is ready. 
# Check that you don't make non-lazy gettext calls at import time.

from Iuppiter.Util import extendUnique
from Iuppiter.DjangoUtil import extendInstalledApps

from Version import ZEPHYRUS_VERSION

def createLogger(name, fileHandlerName):
    logger = logging.getLogger(name)
    logger.setLevel(logging.DEBUG)
    handler = logging.StreamHandler()
    handler.setFormatter(
        logging.Formatter("%(asctime)s - %(levelname)s - %(message)s"))
    logger.addHandler(handler)
    fileHandler = logging.FileHandler(fileHandlerName)
    fileHandler.setLevel(logging.WARNING)
    logger.addHandler(fileHandler)
    return logger

def update(settingsDict, defaults, config=None):
    """
    Update settings by defaults if the key is not in settings.
    
    @param settingsDict Settings dict.
    @param defaults Defaults dict to provide default value.
    @param config Reserved.
    """
    for k, v in defaults.items():
        if k not in settingsDict:
            settingsDict[k] = v

def warnWithout(k, settingsDict, defaults):
    """
    Prompt warning message for without certain key in settings
    while doing attachSettings.
    
    @param k Settings key.
    @param settingsDict Settings dict.
    @param defaults Defaults dict to provide default value.
    """
    if k not in settingsDict:
        warnings.warn("'%s' %s %s" % (
            colored(k, 'yellow', attrs=['bold']),
            colored(" not set in settings.py, it will be set as ", 'white',
                    attrs=['bold']),
            colored(defaults[k], 'cyan', attrs=['bold'])))

def attachSettings(settingsDict):
    if 'ZEPHYRUS_BLOG_ENABLE' in settingsDict:
        ZEPHYRUS_BLOG_ENABLE = settingsDict['ZEPHYRUS_BLOG_ENABLE']
    else:
        ZEPHYRUS_BLOG_ENABLE = False

    #=========================================================================
    # Django plugins.
    ADDING_INSTALLED_APPS = [
        'djangocms_history',
        'djangocms_forms',
        'djangocms_file',
        'djangocms_picture',
        'Zephyrus.boilerplate',
        'Zephyrus.landing',
        'Zephyrus.facebook',
        'drip',
        'Zephyrus.autoresponder',
        'Zephyrus.comment',
    ]

    if ZEPHYRUS_BLOG_ENABLE:
        ADDING_INSTALLED_APPS += [
            'aldryn_apphooks_config',
            'aldryn_categories',
            'aldryn_common',
            'aldryn_newsblog',
            'aldryn_people',
            'aldryn_translation_tools',
            'parler',
            'sortedm2m',
            'taggit',

            'Zephyrus.blog_extension',
        ]

    installed = settingsDict['INSTALLED_APPS']
    keys = [k for k in installed if k.startswith('djangocms_')]
    extendInstalledApps(settingsDict, ADDING_INSTALLED_APPS,
                        key=list(keys)[-1])
    
    #=========================================================================
    # Django CMS Ckeditor.
    DEFAULT_CKEDITOR_SETTINGS = {
        'CKEDITOR_SETTINGS': {
            'language': '{{ language }}',
            'toolbar_CMS': [
                ['cmsplugins',],
                
                ['Source', '-', 'Save', 'NewPage', 'DocProps', 'Preview', 
                 'Print', '-', ' Templates'],
                ['Cut', 'Copy', 'Paste', 'PasteText', 'PasteFromWord', '-', 
                 'Undo', 'Redo'],
                ['Find', 'Replace', '-', 'SelectAll', '-', 'SpellChecker', 
                 'Scayt'],
                ['Form', 'Checkbox', 'Radio', 'TextField', 'Textarea', 'Select', 
                'Button', 'ImageButton', 'HiddenField'],
                ['Bold', 'Italic', 'Underline', 'Strike', 'Subscript', 
                'Superscript', '-', 'RemoveFormat'],
                ['NumberedList', 'BulletedList', '-', 'Outdent', 'Indent', '-', 
                'Blockquote', 'CreateDiv', '-', 'JustifyLeft', 'JustifyCenter', 
                'JustifyRight', 'JustifyBlock', '-', 'BidiLtr', 'BidiRtl'],
                ['Link', 'Unlink', 'Anchor'],
                ['Image', 'Flash', 'Table', 'HorizontalRule', 'Smiley', 
                'SpecialChar', 'PageBreak', 'Iframe'],
                ['Styles', 'Format', 'Font', 'FontSize'],
                ['TextColor', 'BGColor'],
                ['Maximize', 'ShowBlocks', '-', 'About'],
            ],
            'toolbar_HTMLField': [         
                ['Source', '-', 'Save', 'NewPage', 'DocProps', 'Preview', 
                 'Print', '-', ' Templates'],
                ['Cut', 'Copy', 'Paste', 'PasteText', 'PasteFromWord', '-', 
                 'Undo', 'Redo'],
                ['Find', 'Replace', '-', 'SelectAll', '-', 'SpellChecker', 
                 'Scayt'],
                ['Form', 'Checkbox', 'Radio', 'TextField', 'Textarea', 'Select', 
                'Button', 'ImageButton', 'HiddenField'],
                ['Bold', 'Italic', 'Underline', 'Strike', 'Subscript', 
                'Superscript', '-', 'RemoveFormat'],
                ['NumberedList', 'BulletedList', '-', 'Outdent', 'Indent', '-', 
                'Blockquote', 'CreateDiv', '-', 'JustifyLeft', 'JustifyCenter', 
                'JustifyRight', 'JustifyBlock', '-', 'BidiLtr', 'BidiRtl'],
                ['Link', 'Unlink', 'Anchor'],
                ['Image', 'Flash', 'Table', 'HorizontalRule', 'Smiley', 
                'SpecialChar', 'PageBreak', 'Iframe'],
                ['Styles', 'Format', 'Font', 'FontSize'],
                ['TextColor', 'BGColor'],
                ['Maximize', 'ShowBlocks', '-', 'About'],
            ],
            'skin': 'moono-lisa',
        },
        'TEXT_ADDITIONAL_TAGS': (
            'iframe',
        ),
        'TEXT_ADDITIONAL_ATTRIBUTES': (
            'scrolling', 'allowfullscreen', 'frameborder'
        ),
    }
    update(settingsDict, DEFAULT_CKEDITOR_SETTINGS)

    #=========================================================================
    # Django CMS Snippe.
    DEFAULT_SNIPPE_SETTINGS = {
        'DJANGOCMS_SNIPPET_SEARCH': True,
    }
    update(settingsDict, DEFAULT_SNIPPE_SETTINGS)

    #=========================================================================
    # Zephyrus Landing.
    LANDING_FORM_SETTINGS = [
        ('djangocms_forms/form_template/default.html', 'Default'),
        ('landing/LandingForm.html', 'Landing Form'),
    ]

    LANDING_CMS_TEMPLATES = [
        ('landing/ThankYou.html', 'Landing Thank You Page'),
    ]

    if 'DJANGOCMS_FORMS_TEMPLATES' in settingsDict:
        formTemplates = settingsDict['DJANGOCMS_FORMS_TEMPLATES']
    else:
        formTemplates = LANDING_FORM_SETTINGS

    if 'CMS_TEMPLATES' in settingsDict:
        cmsTemplates = settingsDict['CMS_TEMPLATES']
    else:
        cmsTemplates = LANDING_CMS_TEMPLATES


    settingsDict['DJANGOCMS_FORMS_TEMPLATES'] = extendUnique(
        formTemplates, LANDING_FORM_SETTINGS)
    settingsDict['CMS_TEMPLATES'] = extendUnique(
        cmsTemplates, LANDING_CMS_TEMPLATES)
